<?php
/**
 * The template for displaying Comments
 *
 * The area of the page that contains comments and the comment form.
 *
 * @package WordPress
 * @subpackage Jewelrica
 * @since Jewelrica 1.0
 */

/*
 * If the current post is protected by a password and the visitor has not yet
 * entered the password we will return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

if ( ! function_exists( 'toko_comment' ) ) :
function toko_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( 'media' ); ?>>
		<div class="comment-body">
			<?php _e( 'Pingback:', 'tokopress' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'tokopress' ), '<span class="edit-link">', '</span>' ); ?>
		</div>

	<?php else : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
		<article id="div-comment-<?php comment_ID(); ?>" class="comment-body media">
			<div class="row">
				<div class="col-sm-4">
					<footer class="comment-meta">
						<div class="comment-author vcard">
							<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
						</div>
						<div class="author-meta">
							<h5 class="media-heading"><?php printf( '<cite class="fn">%s</cite>', get_comment_author_link() ); ?></h5>
							<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
								<time datetime="<?php comment_time( 'c' ); ?>">
									<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'tokopress' ), get_comment_date(), get_comment_time() ); ?>
								</time>
							</a> 
							<?php edit_comment_link( __( '<span class="fa fa-edit"></span> Edit', 'tokopress' ), '<span class="edit-link">', '</span>' ); ?>
						</div>
					</footer>
				</div>

				<div class="col-sm-8">
					<div class="comment-content">
						<i class="fa fa-angle-left"></i>

						<?php if ( '0' == $comment->comment_approved ) : ?>
							<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'tokopress' ); ?></p>
						<?php endif; ?>
						
						<?php comment_text(); ?>
						
						<?php if ( $tp_reply = get_comment_reply_link( array_merge( $args, array( 'add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ) ) : ?>
						<footer class="reply comment-reply">
							<?php echo str_replace( 'comment-reply-link', 'comment-reply-link', $tp_reply ); ?>
						</footer><!-- .reply -->
						<?php endif; ?>
					</div>
				</div>
			</div>
		</article><!-- .comment-body -->

	<?php
	endif;
}
endif;

?>

<div id="comments" class="comments-area">

	<div class="comments-area-inner">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( _nx( 'One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'tokopress' ),
					number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
			?>
		</h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav id="comment-nav-above" class="comment-navigation" role="navigation">
			<h5 class="screen-reader-text"><?php _e( 'Comment navigation', 'tokopress' ); ?></h5>
			<ul class="pager">
				<li class="previous"><?php previous_comments_link( __( '&larr; Older Comments', 'tokopress' ) ); ?></li>
				<li class="next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'tokopress' ) ); ?></li>
			</ul>
		</nav><!-- #comment-nav-above -->
		<?php endif; // check for comment navigation ?>

		<ol class="comment-list media-list">
			<?php
				/* Loop through and list the comments. Tell wp_list_comments()
				 * to use toko_comment() to format the comments.
				 * If you want to overload this in a child theme then you can
				 * define toko_comment() and that will be used instead.
				 * See toko_comment() in includes/template-tags.php for more.
				 */
				wp_list_comments( array( 'callback' => 'toko_comment', 'avatar_size' => 50 ) );
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav id="comment-nav-below" class="comment-navigation" role="navigation">
			<h5 class="screen-reader-text"><?php _e( 'Comment navigation', 'tokopress' ); ?></h5>
			<ul class="pager">
				<li class="previous"><?php previous_comments_link( __( '&larr; Older Comments', 'tokopress' ) ); ?></li>
				<li class="next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'tokopress' ) ); ?></li>
			</ul>
		</nav><!-- #comment-nav-below -->
		<?php endif; // check for comment navigation ?>

	<?php endif; // have_comments() ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
		<p class="no-comments"><?php _e( 'Comments are closed.', 'tokopress' ); ?></p>
	<?php endif; ?>

	</div><!-- .comments-area-inner -->
	
	<?php 
	$commenter = wp_get_current_commenter();
	$req      = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	comment_form( array(
		'format'				=> 'html5',
		'fields'				=> array(
			'author' 			=> '<p class="form-group comment-form-author"> <label class="sr-only" for="author">' . __( 'Name', 'tokopress' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label><input class="form-control" id="author" name="author" type="text" placeholder="' . __( 'Name', 'tokopress' ) . ( $req ? ' *' : '' ) . '" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>',
			'email'  			=> '<p class="form-group comment-form-email"><label class="sr-only" for="email">' . __( 'Email', 'tokopress' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' . '<input class="form-control" id="email" name="email" type="email" placeholder="' . __( 'Email', 'tokopress' ) . ( $req ? ' *' : '' ) . '" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>',
			'url'    			=> '<p class="form-group comment-form-url"><label class="sr-only" for="url">' . __( 'Website', 'tokopress' ) . '</label> ' . '<input class="form-control" id="url" name="url" type="url" placeholder="' . __( 'Website', 'tokopress' ) . '" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>',
		),	
		'id_form'				=> 'commentform',
		'id_submit'				=> 'commentsubmit',
		'title_reply'			=> __( 'Leave a Comment', 'tokopress' ), 
		'title_reply_to'		=> __( 'Leave a Comment to %s', 'tokopress' ),
		'cancel_reply_link'		=> __( 'Cancel Reply', 'tokopress' ),
		'label_submit'			=> __( 'Post Comment', 'tokopress' ),
		'comment_field'			=> '<p class="form-group comment-form-comment"><label class="sr-only" for="comment">' . __( 'Comment', 'tokopress' ) . '</label><textarea class="form-control" id="comment" name="comment" placeholder="' . __( 'Comment', 'tokopress' ) . ' *" cols="45" rows="5" aria-required="true"></textarea></p>', 
		'comment_notes_after'	=> '<p class="form-allowed-tags">' . __( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes:', 'tokopress' ) . '</p><div class="alert alert-info">' . allowed_tags() . '</div>' 
			  
	)); 
	?>

</div><!-- #comments -->
