<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * @package	   TGM-Plugin-Activation
 * @subpackage Plugins
 * @author	   Thomas Griffin <thomas@thomasgriffinmedia.com>
 * @author	   Gary Jones <gamajo@gamajo.com>
 * @copyright  Copyright (c) 2012, Thomas Griffin
 * @license	   http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
toko_require_file( THEME_DIR . '/inc/core/class-tgm-plugin-activation.php' );

add_action( 'tgmpa_register', 'toko_register_required_plugins' );
function toko_register_required_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		/* Required Plugin */
		array(
			'name'		=> 'WooCommerce',
			'slug'		=> 'woocommerce',
			'required'	=> true,
		),

		/* Recommended Plugin */
		array(
			'name'     	=> 'Visual Composer',
			'slug'     	=> 'js_composer',
			'source'   	=> get_template_directory() . '/inc/plugins/js_composer-v4.6.2.zip',
			'version' 	=> '4.5.3',
			'required' 	=> false,
		),

		array(
			'name'     	=> 'Toko VC & Shortcodes',
			'slug'     	=> 'toko-shortcodes',
			'source'   	=> get_template_directory() . '/inc/plugins/toko-shortcodes-v1.1.zip',
			'version' 	=> '1.1',
			'required' 	=> false,
		),

		array(
			'name'     	=> 'Toko Sliders',
			'slug'     	=> 'toko-sliders',
			'source'   	=> get_template_directory() . '/inc/plugins/toko-sliders-v1.1.zip',
			'version' 	=> '1.1',
			'required' 	=> false,
		),
		
		array(
			'name'		=> 'WordPress Importer',
			'slug'		=> 'wordpress-importer',
			'source'   	=> get_template_directory() . '/inc/plugins/wordpress-importer-v2.0.zip',
			'version' 	=> '2.0',
			'required' 	=> false,
		),
		
		array(
			'name'		=> 'Widget Importer Exporter',
			'slug'		=> 'widget-importer-exporter',
			'required'	=> false,
		),
		
		array(
			'name'		=> 'Regenerate Thumbnails',
			'slug'		=> 'regenerate-thumbnails',
			'required'	=> false,
		),

	);

	// Text Domain
	$theme_text_domain = 'toko';

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'       		=> $theme_text_domain,         	// Text domain - likely want to be the same as your theme.
		'default_path' 		=> '',                         	// Default absolute path to pre-packaged plugins
		'parent_menu_slug' 	=> 'themes.php', 				// Default parent menu slug
		'parent_url_slug' 	=> 'themes.php', 				// Default parent URL slug
		'menu'         		=> 'install-required-plugins', 	// Menu slug
		'has_notices'      	=> true,                       	// Show admin notices or not
		'is_automatic'    	=> true,					   	// Automatically activate plugins after installation or not
		'message' 			=> '',							// Message to output right before the plugins table
		'strings'      		=> array(
			'page_title'                       			=> __( 'Install Required Plugins', 'tokopress' ),
			'menu_title'                       			=> __( 'Install Plugins', 'tokopress' ),
			'installing'                       			=> __( 'Installing Plugin: %s', 'tokopress' ), // %1$s = plugin name
			'oops'                             			=> __( 'Something went wrong with the plugin API.', 'tokopress' ),
			'notice_can_install_required'     			=> _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'			=> _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_cannot_install'  					=> _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_can_activate_required'    			=> _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended'			=> _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_cannot_activate' 					=> _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_ask_to_update' 						=> _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'tokopress' ), // %1$s = plugin name(s)
			'notice_cannot_update' 						=> _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'tokopress' ), // %1$s = plugin name(s)
			'install_link' 					  			=> _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'tokopress' ),
			'activate_link' 				  			=> _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'tokopress' ),
			'return'                           			=> __( 'Return to Required Plugins Installer', 'tokopress' ),
			'plugin_activated'                 			=> __( 'Plugin activated successfully.', 'tokopress' ),
			'complete' 									=> __( 'All plugins installed and activated successfully. %s', 'tokopress' ), // %1$s = dashboard link
			'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );

}

/* Set Visual Composer as Theme part and disable Visual Composer Updater */
if ( function_exists( 'vc_set_as_theme' ) ) 
	vc_set_as_theme( true );

add_filter('vc_load_default_templates','toko_load_vc_templates');
function toko_load_vc_templates( $args ) {
	$args2 = array ( 
		array(
			'name'=> '1. '.__('Jewelrica - Home','tokopress'),
			'image_path'=> THEME_URI . '/images/vc-homepage.png', 
			'content'=>'[vc_row full_width="stretch_row_content_no_spaces" css=".vc_custom_1439536789991{margin-bottom: 0px !important;background-color: #ffffff !important;}"][vc_column width="1/1"][toko_slider id="1929"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1439733758005{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 80px !important;padding-bottom: 30px !important;}"][vc_column width="1/1"][toko_divider line="no" text_position="left" icon_position="hide" title="Special For You" paragraf="Best item collections in 2015 we have in store" icon="fa fa-adjust"][/vc_column][/vc_row][vc_row css=".vc_custom_1439734400036{margin-bottom: 0px !important;padding-bottom: 60px !important;}"][vc_column width="1/1"][toko_wc_products show="" category="brooches" numbers="3" columns="3" orderby="title" order="ASC" carousel="no" paginate="false" hide_free="no" show_hidden="no" title="Featured Products" title_position="hide"][/vc_column][/vc_row][vc_row css=".vc_custom_1439734569149{margin-top: 0px !important;margin-bottom: 0px !important;padding-top: 90px !important;padding-bottom: 30px !important;background-color: #f5f5f5 !important;}" full_width="stretch_row"][vc_column width="1/1" css=".vc_custom_1439734046393{padding-bottom: 30px !important;}"][vc_row_inner css=".vc_custom_1439734506557{margin-bottom: 0px !important;}"][vc_column_inner width="1/1" css=".vc_custom_1439734514225{padding-bottom: 30px !important;}"][toko_banner text_position="left" banner_image="1780" title="Wedding Rings" paragraf1="Brand new life, Brand new rings" paragraf2="Shop Rings" banner_type="big" banner_url="#"][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/2" css=".vc_custom_1439734524172{padding-bottom: 30px !important;}"][toko_banner text_position="right" banner_image="1781" title="Lovely Necklace" paragraf1="New Collection" paragraf2="Shop Necklace" banner_url="#" banner_type="medium"][/vc_column_inner][vc_column_inner width="1/2" css=".vc_custom_1439734531955{padding-bottom: 30px !important;}"][toko_banner text_position="left" banner_image="1782" title="Lovely Errings" paragraf1="New collection" paragraf2="Shop Earrings" banner_url="#" banner_type="medium"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1439734618195{margin-bottom: 0px !important;padding-top: 90px !important;padding-bottom: 50px !important;background-color: #ffffff !important;}"][vc_column width="1/1"][vc_row_inner css=".vc_custom_1439734668701{padding-bottom: 60px !important;}"][vc_column_inner el_class="" width="1/1"][toko_call_to_action button_type="button" text_position="center" title="June Sale" title_strong="50%" paragraf="Limited Only 10 Days" button_text="Shop Now" button_url="#"][/vc_column_inner][/vc_row_inner][vc_row_inner css=".vc_custom_1439731815984{margin-bottom: 0px !important;}"][vc_column_inner width="1/1" css=".vc_custom_1439745268547{padding-bottom: 30px !important;}"][toko_divider line="no" text_position="left" icon_position="hide" title="Best Selling" paragraf="Best item collection in 2015 we have in store" icon="fa fa-adjust"][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner el_class="" width="1/1"][toko_wc_products title="Best Selling Products" title_position="hide" numbers="3" columns="3" carousel="no" paginate="false"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]', 
		),
	);
	return array_merge( $args, $args2 );
}
