<?php

/* WooCommerce Theme Support */
add_theme_support( 'woocommerce' );

/* Ensure cart contents update when products are added to the cart via AJAX (place the following in functions.php) */
add_filter('add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment');
function woocommerce_header_add_to_cart_fragment( $fragments ) {
	$fragments['.header-topnav .cart-subtotal .topnav-label'] = '<span class="topnav-label">'. WC()->cart->get_cart_subtotal() .'</span>';
	return $fragments;
}

/* Remove Sidebar */
remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );

/* Remove Breadcrumb */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

/* Shop Page - Products Per Page */
add_filter( 'loop_shop_per_page', 'toko_wc_shop_products_per_page', 20 );
function toko_wc_shop_products_per_page( $number ) {
	$per_page = intval( toko_get_option( 'wc_shop_number' ) );
	if ( $per_page < 1 ) $per_page = 12;
	return $per_page;
}

add_action( 'wp', 'toko_wc_setup_shop_page' );
function toko_wc_setup_shop_page() {

	/* Shop Page - Number of Products Columns Per Row */	
	add_filter( 'loop_shop_columns', 'toko_wc_shop_columns', 20 );
	add_filter( 'body_class', 'toko_wc_body_class_product_columns' );

	/* Shop Page - Results Count */
	if( toko_get_option( 'wc_shop_result_count_disable' ) ) {
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
	}

	/* Shop Page - Catalog Ordering */
	if( toko_get_option( 'wc_shop_catalog_ordering_disable' ) ) {
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
	}

	/* Shop Page - Sale Flash */
	if( toko_get_option( 'wc_shop_saleflash_disable' ) ) {
		remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
	}

	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );

	/* Shop Page - Product Price */
	if( ! toko_get_option( 'wc_shop_cat_disable' ) ) {
		add_action( 'woocommerce_before_shop_loop_item_title', 'toko_shop_item_category', 101 );
	}

	/* Shop Page - Product Price Box */
	add_action( 'woocommerce_after_shop_loop_item_title', 'toko_wrapper_detail_item_start', 3 );
	add_action( 'woocommerce_after_shop_loop_item_title', 'toko_wrapper_detail_item_end', 20 );

	/* Shop Page - Product Price */
	if( toko_get_option( 'wc_shop_price_disable' ) ) {
		remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
	}

	/* Shop Page - Product Rating */
	if( toko_get_option( 'wc_shop_rating_disable' ) ) {
		remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
	}

	/* Shop Page - Product "Add To Cart" Button */
	if( ! toko_get_option( 'wc_shop_addtocart' ) ) {
		remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
	}

	/* Shop Page - Pagination Style */
	remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );
	add_action( 'woocommerce_after_shop_loop', 'toko_pagination', 10 );

}

function toko_wc_shop_columns( $columns ) {
	$columns = intval( toko_get_option( 'wc_shop_columns' ) );
	if ( $columns < 1 ) $columns = 3;
	if ( $columns > 4 ) $columns = 4;
	return $columns;
}
function toko_wc_body_class_product_columns( $classes ) {
	if ( is_woocommerce() ) {
		$columns = apply_filters( 'loop_shop_columns', 3 );
		if ( $columns < 1 ) $columns = 3;
		if ( $columns > 4 ) $columns = 4;
		$classes[] = 'columns-' . $columns;
	}
	return $classes;
}
function toko_custom_add_to_cart_text() {
	return '';
}
function toko_wrapper_detail_item_start() {
	echo '<div class="product-price-box clearfix">';
}
function toko_wrapper_detail_item_end() {
	echo '</div>';
}
function toko_shop_item_category() {
	$args = array( 'fields' => 'names' );
	$terms_cat = wp_get_post_terms( get_the_ID(), 'product_cat', $args );
	$i=1;
	foreach ( $terms_cat as $termName ) {
		if( $i <= 1 ) {
			echo '<span class="product-category">' . $termName . '</span>';
		}
	$i++;
	}
}

add_action( 'wp', 'toko_wc_setup_product_page' );
function toko_wc_setup_product_page() {

	/* Single Product - Sale Flash */
	if( toko_get_option( 'wc_product_saleflash_disable' ) ) {
		remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );
	}

	/* Single Product - Rating */
	if( toko_get_option( 'wc_product_rating_disable' ) ){
		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
	}

	/* Single Product - Price */
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
	if( !toko_get_option( 'wc_product_price_disable' ) ) {
		add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 25 );
	}

	/* Single Product - Short Description */
	if( toko_get_option( 'wc_product_excerpt_disable' ) ){
		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
	}

	/* Single Product - Add To Cart */
	if( toko_get_option( 'wc_product_addtocart_disable' ) ) {
		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );
	}

	/* Single Product - Meta */
	if( toko_get_option( 'wc_product_meta_disable' ) ) {
		remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
	}

	/* Single Product - Upsells */
	if( toko_get_option( 'wc_product_upsells_disable' ) ) {
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
	}

	/* Single Product - Related */
	if( toko_get_option( 'wc_product_related_disable' ) ) {
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	}
}

/* Single Product - Product Thumbnail Columns */
add_filter( 'woocommerce_product_thumbnails_columns', 'toko_default_product_thumbnail_columns' );
function toko_default_product_thumbnail_columns( $column ) {
	$column = 4;
	return $column;
}

add_filter( 'woocommerce_product_tabs', 'toko_wc_product_tabs', 99 );
function toko_wc_product_tabs( $tabs ) {

	/* Single Product - Tabs - Description */
	if( toko_get_option( 'wc_product_description_disable' ) ) {
		unset( $tabs['description'] );
	}

	/* Single Product - Tabs - Attributes */
	if( toko_get_option( 'wc_product_attributes_disable' ) ) {
		unset( $tabs['additional_information'] );
	}

	/* Single Product - Tabs - Reviews */
	if( toko_get_option( 'wc_product_reviews_disable' ) ) {
	    unset( $tabs['reviews'] );
	}
    return $tabs;
}

/* Single Product - Upsells */
function woocommerce_upsell_display( $posts_per_page = '-1', $columns = 3, $orderby = 'rand' ) {
	$columns = apply_filters( 'loop_shop_columns', 3 );
	if ( $columns < 1 ) $columns = 3;
	if ( $columns > 4 ) $columns = 4;
	wc_get_template( 'single-product/up-sells.php', array(
			'posts_per_page'	=> $posts_per_page,
			'orderby'			=> apply_filters( 'woocommerce_upsells_orderby', $orderby ),
			'columns'			=> $columns
		) );
}

/* Single Product - Related */
add_filter( 'woocommerce_output_related_products_args', 'toko_wc_output_related_products_args' );
function toko_wc_output_related_products_args( $args ) {
	$columns = apply_filters( 'loop_shop_columns', 3 );
	if ( $columns < 1 ) $columns = 3;
	if ( $columns > 4 ) $columns = 4;
	$args = array(
		'posts_per_page' 	=> $columns,
		'columns' 			=> $columns,
		'orderby' 			=> 'rand'
	);
	return $args;
}

add_action( 'wp', 'toko_wc_setup_cart_page' );
function toko_wc_setup_cart_page() {
	if( toko_get_option( 'wc_product_cross_sells_disable' ) ) {
		remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
	}
}

/* Cart Page - Cross Sells */
function woocommerce_cross_sell_display( $posts_per_page = 3, $columns = 3, $orderby = 'rand' ) {
	$columns = apply_filters( 'loop_shop_columns', 3 );
	if ( $columns < 1 ) $columns = 3;
	if ( $columns > 4 ) $columns = 4;
	$posts_per_page = $columns;
	wc_get_template( 'cart/cross-sells.php', array(
			'posts_per_page' => $posts_per_page,
			'orderby'        => $orderby,
			'columns'        => $columns
		) );
}

/* My Account - Login Redirect */
add_filter( 'woocommerce_login_redirect', 'toko_wc_login_redirect' );
function toko_wc_login_redirect( $redirect_to ) {
	if( toko_get_option( 'wc_redirect_after_login' ) ) {
	    $redirect_to = esc_url( toko_get_option( 'wc_redirect_after_login' ) );
	}
    return $redirect_to;
}

